podgen.Person — PodGen Documentation

# podgen.Person

class `podgen.` `Person`(name=None, email=None)

  Data-oriented class representing a single person or entity.

  A Person can represent both real persons and less personal entities like organizations. Example:

      >>> p.authors = [Person("Example Radio", "mail@example.org")]

  Note

  At any time, one of name or email must be present. Both cannot be None or empty at the same time.

  Warning

  Any names and email addresses you put into a Person object will eventually be included and published together with the feed. If you want to keep a name or email address private, then you must make sure it isn’t used in a Person object (or to be precise: that the Person object with the name or email address isn’t used in any Podcast or Episode.)

  Example of use:

      >>> from podgen import Person
      >>> Person("John Doe")
      Person(name=John Doe, email=None)
      >>> Person(email="johndoe@example.org")
      Person(name=None, email=johndoe@example.org)
      >>> Person()
      ValueError: You must provide either a name or an email address.

  `email`

    This person’s public email address.

    Type: | `str`

  `name`

    This person’s name.

    Type: | `str`